@@ -335,7 +335,7 @@ def change_bulkstatus_to_string(df):
         logger.info(f"{df['BulkStatus'].value_counts()}")
     return df
 
-def impute_growth(df,impute_growth_flag):
+def impute_growth(df,impute_growth_flag=1):
     if impute_growth_flag==1:
         logger.info("Applying growth imputation")
         df['Growth12M']=df['Growth12M'].fillna(df['Growth6M'])
